summaryrefslogtreecommitdiff
path: root/src/or/main.c
diff options
context:
space:
mode:
authorRoger Dingledine <arma@torproject.org>2011-09-13 18:32:00 -0400
committerRoger Dingledine <arma@torproject.org>2011-09-13 18:32:00 -0400
commit1fcaeb60924d155e80a9579588a1b6c31e2174f7 (patch)
tree274aa165a9ade0fbf3b9b1ce940d2e91c531d96a /src/or/main.c
parent1e1cc43b5723008dc6ec19188b1613c3682c36d3 (diff)
parent4a351b4b9ebfadf27d68e6bb3e1470cdef83ef45 (diff)
downloadtor-1fcaeb60924d155e80a9579588a1b6c31e2174f7.tar.gz
tor-1fcaeb60924d155e80a9579588a1b6c31e2174f7.zip
Merge branch 'maint-0.2.2'
Diffstat (limited to 'src/or/main.c')
-rw-r--r--src/or/main.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/or/main.c b/src/or/main.c
index af769c412b..ad5558e649 100644
--- a/src/or/main.c
+++ b/src/or/main.c
@@ -1152,15 +1152,16 @@ run_scheduled_events(time_t now)
if (options->UseBridges)
fetch_bridge_descriptors(options, now);
/** 1b. Every MAX_SSL_KEY_LIFETIME seconds, we change our TLS context. */
if (!last_rotated_x509_certificate)
last_rotated_x509_certificate = now;
- if (last_rotated_x509_certificate+MAX_SSL_KEY_LIFETIME < now) {
+ if (last_rotated_x509_certificate+MAX_SSL_KEY_LIFETIME_INTERNAL < now) {
log_info(LD_GENERAL,"Rotating tls context.");
if (tor_tls_context_init(public_server_mode(options),
get_tlsclient_identity_key(),
is_server ? get_server_identity_key() : NULL,
- MAX_SSL_KEY_LIFETIME) < 0) {
+ MAX_SSL_KEY_LIFETIME_ADVERTISED) < 0) {
log_warn(LD_BUG, "Error reinitializing TLS context");
/* XXX is it a bug here, that we just keep going? -RD */
}
@@ -1152,15 +1152,16 @@ run_scheduled_events(time_t now)
if (options->UseBridges)
fetch_bridge_descriptors(options, now);
- /** 1b. Every MAX_SSL_KEY_LIFETIME seconds, we change our TLS context. */
+ /** 1b. Every MAX_SSL_KEY_LIFETIME_INTERNAL seconds, we change our
+ * TLS context. */
if (!last_rotated_x509_certificate)
last_rotated_x509_certificate = now;